/* migstat05_sas.zip: 05 Grosseltern-Eltern 2005.sas

   2. Identifikation von 3-Generationen-Haushalten */

OPTIONS NOFMTERR; RUN;   /* ohne Formate */

libname mzjahr '<Arbeitsverzeichnis'>;

/*	Eltern im Haushalt isolieren, (Vater ueber EF54/EF55, Mutter EF52/EF53) und 
	Kind-Elternbezug in Tabelle eintragen */
data mzjahr.KindEltern (Keep=EF1 EF3 EF4 EF5 EF12 Typ PNr); 

	set mzjahr.<mz2005>;

/*	Vater im Haushalt? Wenn ja, Ausgabe mit Typ=1 und PNr=EF55 */
	if EF54 =1 then do;
		Typ=1; PNr=EF55; output mzjahr.KindEltern; 
	end;

/*	Mutter im Haushalt? Wenn ja, Ausgabe mit Typ=2 und PNr=EF53 */
	if EF52 =1 then do;
		Typ=2; PNr=EF53; output mzjahr.KindEltern;
	end;
run;

/*	Elterndatei erstellen durch Loeschen doppelter Eintraege in der Datei KindEltern, 
	die als Folge von mehr als einem Kind in der Familie auftreten */
proc sql;
create table mzjahr.Eltern as
	select distinct a.ef1, a.ef3, a.ef4, a.ef5, a.ef12, a.ef52,
		a.ef53, a.ef54, a.ef55
	from mzjahr.<mz2005> as a, mzjahr.KindEltern as b
	where a.ef1=b.ef1 and a.ef3=b.ef3 and a.ef4=b.ef4 
		and a.ef12=b.ef12 and a.ef5=b.PNr 
	order by a.ef1, a.ef3, a.ef4, a.ef5, a.ef12;
quit;

/*	Grosseltern im Haushalt isolieren (Vater ueber EF54/EF55, Mutter EF52/EF53) und 
	Eltern-Grosselternbezug in Tabelle eintragen.
	Ausgangsmaterial ist die Elterndatei */
data mzjahr.ElternGrosseltern (Keep=EF1 ef3 ef4 ef5 EF12 Typ PNr);

/*	Reihenfolge der Variablen festlegen */
    retain EF1 ef3 ef4 ef5 EF12 Typ PNr;

    set mzjahr.Eltern;

/*	Grossvater im Haushalt? Wenn ja, Ausgabe mit Typ=1 und PNr=EF55 */
    if EF54 =1 then do;
        typ=1; PNr=EF55; output mzjahr.ElternGrosseltern;
    end;

/*	Grossmutter im Haushalt? Wenn ja, Ausgabe mit Typ=2 und PNr=EF53 */
    if EF52 =1 then do;
        typ=2; PNr=EF53; output mzjahr.ElternGrosseltern;
    end;
run;

/*	Grosselterndatei erstellen durch Loeschen doppelter Eintraege in der Datei
	Grosseltern, die als Folge von mehr einem Kind der Grosseltern auftreten */
proc sql;
create table mzjahr.GrossEltern as
	select distinct a.ef1, a.ef3, a.ef4, a.ef5, a.ef12, a.ef52,
		a.ef53, a.ef54, a.ef55
	from mzjahr.<mz2005> as a, mzjahr.ElternGrosseltern as b
	where a.ef1=b.ef1 and a.ef3=b.ef3 and a.ef4=b.ef4 
		and a.ef12=b.ef12 and a.ef5=b.PNr 
	order by a.ef1, a.ef3, a.ef4, a.ef5, a.ef12;
quit;


