/* migstat05_sas.zip: 09 Zeitreihenkompatibilitaet 2005.sas

 6. Zeitreihenkompatibilitaet 2005 */

OPTIONS NOFMTERR; RUN;   /* ohne Formate */

/* Arbeitsverzeichnis in '<...>' eintragen; z. B. c:\temp */
libname mzjahr '< >';


/*	In den Jahren 2005 und 2009 laesst sich aufgrund der Zusatzangaben 
	zum Migrationsstatus der nicht im Haushalt lebenden Eltern der 
	Migrationshintergrund von mehr Menschen erkennen als in den anderen Jahren.
	Das schraenkt die Zeitreihenanalyse ein.

	Deshalb wird nachstehend der Migrationsstatus der Menschen in 2005/2009
	simuliert, der sich ergeben haette, wenn lediglich die Angaben aus den anderen
	Jahren zur Verfuegung gestanden haetten.

	In der Datei ZRKompatibel wird der Migstatus fuer 2005 entsprechend umgesetzt.
	Betroffen sind lediglich die Deutschen mit einseitigem und beidseitigem 
	Migrationshintergrund Codes 61 bzw. 62-64 
	
	Es gelten folgende Regeln:
	Einseitiger MigH: Angaben zum bestimmenden Elternteil fehlen:
	Code: 52 -> 72
	Code: 53 -> 73
	Code: 54 -> 74
	Beidseitiger MigH: Angaben zu einem bestimmenden Elternteil fehlen:
	Code: 62 -> 57
	Code: 63 -> 58
	Code: 64 -> 59
	Beidseitiger MigH: Angaben zu beiden bestimmenden Elternteilen fehlen:
	Code: 62 -> 77
	Code: 63 -> 78
	Code: 64 -> 79 */

Data mzjahr.ZRTypisiert (KEEP=EF1 EF3 EF4 EF5 EF12 EF30 Berichtsjahr Geschlecht 
	Jahrzuzug Problem 
	MIG     MIGS   MIGS_R  /* Migstatus und Staatsangeh. zeitreihenkompatibel */
	MIG2005 MIGS2005       /* Migstatus und Staatsangeh. nur fuer 2005 */
	EF369   EF374   EF353    EF382   EF361   EF365   /* recodierte Var */
	EF369_O EF374_O EF353_O  EF382_O EF361_O EF365_O /* Originalfassungen */
	MigAlt MigNeu SA1 SA2 SA3 SA SA_erw MIGV SAV SA_erwV MIGM SAM SA_erwM
	ISVE MIGVE SAVE SA_erwVE MIGVI SAVI SA_erwVI 
	ISME MIGME SAME SA_erwME MIGMI SAMI SA_erwMI 
	AHRFQ Anzahl 
        EF53 EF55
	/* Kontrollvariablen */
	MIG_ALT SA_erw_ALT
	migs pe pi Fall);

	retain EF1 EF3 EF4 EF5 EF12 EF53 EF55 EF30 AHRFQ 
	MIG     MIGS     MIGS_R
	MIG2005 MIGS2005
	EF369   EF374   EF353    EF382   EF361   EF365   
	EF369_O EF374_O EF353_O  EF382_O EF361_O EF365_O 
	Berichtsjahr Geschlecht Jahrzuzug 
	Problem MIG MIGAlt MigNeu SA1 SA2 SA3 SA SA_erw MIGV SAV SA_erwV MIGM SAM SA_erwM
	ISVE MIGVE SAVE SA_erwVE MIGVI SAVI SA_erwVI 
	ISME MIGME SAME SA_erwME MIGMI SAMI SA_erwMI
	Anzahl 
	EF369_O EF374_O EF353_O  EF382_O EF361_O EF365_O
	MIG_ALT SA_erw_ALT
    	pe pi Fall;

/*  Quelle ist die Datei 'BefragteTypisiert' */
	set mzjahr.BefragteTypisiert;

/* Sicherung MIG und SA_erw (Stand: Endtypisierung Befragte) vor Recodierungen */
	MIG_ALT = MIG;
	SA_erw_ALT = SA_erw;


/* Migstatus und Staatsangeh. nur fuer 2005 - nicht zeitreihenkompatibel */
	MIG2005 = mig;  
	if MIG2005 = 29 then MIG2005=21;  /* Recodierung wie SUF 2008, 2009 */
	Label MIG2005 = "[MIG2005] Migrationsstatus 2005 - jahrgangsspezifisch";

	MIGS2005 = SA_erw;                
	if MIG2005 in (0,11) then MIGS2005=0; /* fuer einheimische Bev.: "Entfaellt" */
	Label MIGS2005 = "[MIGS2005] Erw. Staatsangeh. zum Migrationsstatus 2005 - jahrgangsspezifisch";


/*	--------------------------------------------------------------------------- */
/*	Hier folgt der Code zur Umsetzung des Migrationsstatus in den Jahren 2005 und 2009 */

if Berichtsjahr in (2005, 2009) then do;

/*  Probleme treten auf, wenn 
	Mig=52-54, 62-64 UND (ISVE/ISME=1) (Angaben zu externen Eltern)
	oder
	Mig=52-54, 61-64 UND ((ISVE/ISME=0 UND MIGVI/MIGMI=.)
	Konsequenzen:
	Umsetzung des Migrationsstatus MIG fuer die Betroffenen */

/*  Vorbelegung */
	Problem=0; MigAlt=MIG; MigNeu=MIG;

/*  Problemfaelle bestimmen und kennzeichnen */

/*  ---------------------------------------------------------------------*/
/*  bei beidseitigem Migrationshintergrund ist der Fall kritisch, 
	wenn mindestens fuer einen Elternteil Angaben fehlen */
	if MIG in (62,63,64) then do;
/*	wenn keinen internen Angaben fuer Vater vorhanden... */
		if ((ISVE=1) or (ISVE=0 and MIGVI=.))  then do;
/*	... und keine internen Angaben fuer Mutter vorhanden ... */
			if ((ISME=1) or (ISME=0 and MIGMI=.)) then do;
/*	... dann waere 2006-2008/2010-2012 kein Migrationshintergrund erkennbar ... */
				Problem=1; MigNeu=MIG+15; /* 62-64 -> 77-79 */
			end;
/*	... aber interne Angaben fuer Mutter vorhanden ... */
			else do;
/*	... dann bestuende in 2006-2008/2010-2012 ein einseitiger Migrationshintergrund ... */
				Problem=1; 
				if MIGMI in (21,22,23,25,29) then MigNeu=57;
				else if MIGMI in (41,42,43) then MigNeu=59;
				else MigNeu=58;
			end;
		end;
/*	wenn hingegen interne Angaben fuer Vater vorhanden... */
		else do;
/*	... und keine internen Angaben fuer Mutter vorhanden ... */
			if ((ISME=1) or (ISME=0 and MIGMI=.)) then do;
/*	... dann bestuende in 2006-2008/2010-2012 ein einseitiger Migrationshintergrund ... */
				Problem=1; 
				if MIGVI in (21,22,23,25,29) then MigNeu=57;
				else if MIGVI in (41,42,43) then MigNeu=59;
				else MigNeu=58;
			end;
/*	... ansonsten bleibt alles beim Alten */
		end;
	end;
/*  bei einseitigem Migrationshintergrund ist der Fall nur dann kritisch,
	wenn fehlende Elternteil jener mit dem Migrationshintergrund ist */
	if MIG in (52,53,54) then do;
		if MIGV in (21,22,23,25,29,31,32,33,41,42,43,61,62,63,64) and ISVE=1 then do;
			Problem=1; MigNeu=MIG+20; /* 52-54 -> 72-74 */ 
		end;
		else if MIGM in (21,29,23,25,31,32,33,41,42,43,61,62,63,64) and ISME=1 then do;
			Problem=1; MigNeu=MIG+20;
		end;
	end;

end; /* if Berichtsjahr in (2005, 2009) then do; */


/* ====================================================================
Recodierung fuer Zeitreihenkompatibilitaet

Die folgende Recodierung unterscheidet sich geringfuegig von der Original-Syntax. 
Es wird beruecksichtigt, dass die Variablen IsVE und IsME (EF349 bzw. 
EF357 8 "Vater bzw. Mutter lebt nicht im Haushalt") teilweise unplausible 
Angaben enthalten und durchaus Angaben zu den im Haushalt lebenden Eltern 
vorliegen. Um entsprechende Probleme zu vermeiden, wird die Hilfsvariable PI 
(interne) Angaben zu den im Haushalt lebenden Eltern verwendet. */

Fall = 0;
migalt = MIG_ALT;
mig  = MIG_ALT; 
migs = SA_erw_ALT; 

/* Kombination Angaben zu Eltern */
/* pe "Externe Angaben zu den Eltern" */
pe = (isve=0 & isme=0);         /* keine externen Angaben zu den Eltern */
if (isve=1 & isme=1) then pe=2; /* externe Angaben zu beiden Eltern */
if (isve=1 & isme=0) then pe=3; /* externe Angaben nur zum Vater */
if (isve=0 & isme=1) then pe=4; /* externe Angaben nur zur Mutter */

/* pi "Interne Angaben zu den Eltern" */
pi = (ef55=99 & ef53=99);         /* keine internen Angaben zu den Eltern */
if (ef55<99 & ef53<99) then pi=2; /* interne Angaben zu beiden Eltern */
if (ef55<99 & ef53=99) then pi=3; /* interne Angaben nur zum Vater */
if (ef55=99 & ef53<99) then pi=4; /* interne Angaben nur zur Mutter */
/* Korrektur: Einige Haushalte sind unvollstaendig. Deshalb werden 
keine Eltern gefunden, obwohl die Zeigervariablen (EF53, EF55) gueltige
Angaben enthalten. */
if migvi=.  & migmi^=. then pi=4;
if migvi^=. & migmi=.  then pi=3;
if migvi=.  & migmi=.  then pi=1;



/* Fall 1: Beidseitiger MigH der Person (migalt>=62 & migalt<=64)
           Angaben zu beiden bestimmenden Elternteilen fehlen (PI=1) */
if ((migalt>=62 & migalt<=64) & (pi=1)) then Fall = 1;
if ((migalt>=62 & migalt<=64) & (pi=1)) then mig = migalt + 15;
if ((migalt>=62 & migalt<=64) & (pi=1)) then migs = 99;        

/* Fall 2: Interne Angaben fuer Mutter vorhanden (PI=4)
           ... dann einseitiger Migrationshintergrund */
if	((migalt>=62 & migalt<=64) & (pi=4) & (migmi>=0  & migmi<=77)) | 
	((migalt>=62 & migalt<=64) & (pi=4) & (migmi>=21 & migmi<=29)) | 
	((migalt>=62 & migalt<=64) & (pi=4) & (migmi>=41 & migmi<=43)) then Fall=2;
if ((migalt>=62 & migalt<=64) & (pi=4) & (migmi>=0  & migmi<=77)) then mig = 58;
if ((migalt>=62 & migalt<=64) & (pi=4) & (migmi>=21 & migmi<=29)) then mig = 57; 
if ((migalt>=62 & migalt<=64) & (pi=4) & (migmi>=41 & migmi<=43)) then mig = 59; 
if ((migalt>=62 & migalt<=64) & (pi=4) & (migmi>=0  & migmi<=77)) then migs = 99;
if ((migalt>=62 & migalt<=64) & (pi=4) & (migmi>=21 & migmi<=29)) then migs = 99;
if ((migalt>=62 & migalt<=64) & (pi=4) & (migmi>=41 & migmi<=43)) then migs = 99; 


/* Fall 3: Interne Angaben fuer Vater vorhanden (PI=3) und 
           keine internen Angaben fuer Mutter vorhanden 
           ... dann einseitiger Migrationshintergrund  */
if	((migalt>=62 & migalt<=64) & (pi=3) & (migvi>=0  & migvi<=77)) |
	((migalt>=62 & migalt<=64) & (pi=3) & (migvi>=21 & migvi<=29)) |
	((migalt>=62 & migalt<=64) & (pi=3) & (migvi>=41 & migvi<=43)) then Fall=3;
if ((migalt>=62 & migalt<=64) & (pi=3) & (migvi>=0  & migvi<=77)) then mig = 58;
if ((migalt>=62 & migalt<=64) & (pi=3) & (migvi>=21 & migvi<=29)) then mig = 57;
if ((migalt>=62 & migalt<=64) & (pi=3) & (migvi>=41 & migvi<=43)) then mig = 59;
if ((migalt>=62 & migalt<=64) & (pi=3) & (migvi>=0  & migvi<=77)) then migs = 99;
if ((migalt>=62 & migalt<=64) & (pi=3) & (migvi>=41 & migvi<=43)) then migs = 99;
if ((migalt>=62 & migalt<=64) & (pi=3) & (migvi>=21 & migvi<=29)) then migs = 99;

/* Fall 4: Einseitiger Migrationshintergrund (migalt>=52 & migalt<=54)
*          Externe Angaben zum Vater (ISVE=1) ohne
*          interne Angaben zum Vater (EF55=99) ... dann Code 52-54 -> 72-74 */
if ( migalt>=52 & migalt<=54 & isve=1 & EF55=99 & migv in (21,22,23,25,29,31,32,33,41,42,43,61,62,63,64)) then Fall=4;
if ( migalt>=52 & migalt<=54 & isve=1 & EF55=99 & migv in (21,22,23,25,29,31,32,33,41,42,43,61,62,63,64)) then mig = migalt + 20;
if ( migalt>=52 & migalt<=54 & isve=1 & EF55=99 & migv in (21,22,23,25,29,31,32,33,41,42,43,61,62,63,64)) then migs = 99;

/* Fall 5: Einseitiger Migrationshintergrund (migalt>=52 & migalt<=54)
           Externe Angaben zur Mutter (ISME=1) ohne
           interne Angaben zur Mutter (EF53=99)... dann Code 52-54 -> 72-74 */
if ( migalt>=52 & migalt<=54 & isme=1 & EF53=99 & migm in (21,22,23,25,29,31,32,33,41,42,43,61,62,63,64)) then Fall=5;
if ( migalt>=52 & migalt<=54 & isme=1 & EF53=99 & migm in (21,22,23,25,29,31,32,33,41,42,43,61,62,63,64)) then mig = migalt + 20;
if ( migalt>=52 & migalt<=54 & isme=1 & EF53=99 & migm in (21,22,23,25,29,31,32,33,41,42,43,61,62,63,64)) then migs = 99;


/* MIGS (ex SA_erw) fuer einheimische Bevoelkerung auf 0 Entfaellt setzen 

ZU BEACHTEN: 
MIGS stimmt nicht vollstaendig mit Fachserienergebnissen ueberein, da die 
Codierungen der Angaben zu den Staatsangehoerigkeiten der Eltern ausserhalb des 
Haushalts von den Angaben zur Person aufgrund von Vergroeberungen abweichen. */

if mig = 29 then mig = 21;  /* Recodierung wie SUF 2008, 2009 */

if mig in (0,11) then migs =0;

Label MIG  = "[MIG] Migrationsstatus 2005 zeitreihenkompatibel"; 
Label MIGS = "[MIGS] Erw. Staatsangeh. zum Migrationsstatus 2005 zeitreihenkompatibel";


/* 7. Variablendefinition fuer SUF- und Fachserien-Ergebnisse */
/* Fuer Vergleiche mit 
Statistisches Bundesamt (2009): Fachserie 1 Reihe 2.2, Tabelle 2, S. 60.

STAATSANGEHOERIGKEITEN zum Migrationsstatus zeitreihenkompatibel (MIG).
Deutsche Zuwanderer ohne Einbuergerung sowie in Deutschland geborene .
Deutsche mit ein-/beidseitigem Migrationshintergund => 0 (deutsch) */
	MIGS_R = MIGS;
	if MIG in (0,11,21,22,23,25,29,61,62,63,64,71,72,73,74) then MIGS_R = 0;

Label MIGS_R = "[MIGS_R] Erw. Staatsangeh. zum Mig-status 2005 zeitreihenkompatibel recodiert";


proc format; 
value migsr (multilabel notsorted)
	0-99 = "Z05 Insgesamt"
	1-7  = "Z06 Europa"
	1-3  = "Z07 - EU-25"
	1    = "Z10   + Polen"
	4-7  = "Z11 Sonstiges Europa"
	8    = "Z19 Afrika"
	10   = "Z23 Naher und Mittlerer Osten inkl. Kasachstan"
	0,99 = "Z26 k.A., unzutreffend";
/*	9    = "Amerika, Uebr.Welt, Staatenlos"
	11   = "Asien (Rest)" */
run;


proc format;
value migstat (multilabel notsorted)  /* Z___: Zeilennummer in Tab. 2, Fachserie 1, Reihe 2.2 */
	0-79                 = "Z001 Bevoelkerung insgesamt (0-79)"
	0,11                 = "Z002 Personen ohne Mig-hintergrund (0,11)"
	21-79                = "Z003 Personen mit Mig-hintergrund i.w.S. (21-79)"
	72-79                = "Z004 dar.: Mig-status nicht durchweg bestimmbar (72-79)"
	21-64                = "Z005 Personen mit Mig-hintergrund i.e.S. (21-64)"
	21-29,31,41          = "Z034 Personen mit eigener Mig-erfahrung (21-29,31,41)"
	41                   = "Z062 - Auslaender ... (41)"
	21-29,31             = "Z089 - Deutsche  ... (21-29,31)"
	21-29                = "Z090   + ohne Einbuergerung (21-29)"
	31                   = "Z097   + durch Einbuergerung (31)"
	32,42-43,52-59,62-64 = "Z119 Personen ohne eig. Mig-erf. (32,42,43,52-64)"
	42-43                = "Z126 - Auslaender ... (42-43)"
	32,52-64             = "Z133 - Deutsche  ... (32,52-64)"
	32                   = "Z134   + durch Einbuergerung (32)"	
    52-64                = "Z140   + mit mind 1 zugew. o. als Ausl. in D geb. Elternteil (52-64)"
    62-64                = "Z141     # mit beidseitigem Mig-hintergrund (62-64)"
	52-59                = "Z142     # mit einseitigem Mig-hintergrund (52-59)";
run;

/* ENDE MIG-TYPISIERUNG */


/* AUSWERTUNGEN: Fallzahlen */
proc freq data=mzjahr.ZRTypisiert; 
	tables MIG     MIGS /missing;      /* zeitreihenkompatibel */
	tables MIG2005 MIGS2005  /missing; /* jahrgangsspezifisch */
run;

/* Auswertungen fuer Vergleich von SUF- und Fachserien-Ergebnissen */
/* Hochgerechnete Fallzahlen, Bevoelkerung am Hauptwohnort */
proc freq data=mzjahr.ZRTypisiert (where=(ef30>=1 & ef30<=2)); 
 	weight AHRFQ;  /* EF952/0,7 */
	tables MIG2005  MIG  /missing;
	tables MIGS2005 MIGS /missing;
run;


/* Vergleich mit Tab. 2, FS 1, R 2.2
MIG (2005 zeitreihenkompatibel - 
hochgerechnet, Bevoelkerung am Hauptwohnort */
proc means data=mzjahr.ZRTypisiert (keep=EF30 AHRFQ MIG) SUM nonobs; 
	where (EF30>=1 & ef30<=2); /* Bevoelkerung am Hauptwohnsitz */
	var  ahrfq;
	format MIG migstat.;
	class MIG / mlf order=fmt; 
run;


/* Vergleich mit Tab. 2, FS 1, R 2.2 
MIGS (2005 zeitreihenkompatibel, alternative Syntax - 
hochgerechnet, Bevoelkerung am Hauptwohnort 
Personen mit Migrationshintergrund im engeren Sinn (mig=21-64) */
proc means data=mzjahr.ZRTypisiert (keep=EF30 AHRFQ mig MIGS_R) SUM nonobs; 
	where (EF30>=1 & ef30<=2 & mig>=21 & mig<=64); /* Bevoelkerung am Hauptwohnsitz */
	var  ahrfq;
	format MIGS_R migsr.;
	class MIGS_R / mlf order=fmt; 
run;


* ++++++++++++++++++++++ PROGRAMMENDE +++++++++++++++++++++++++++++++;
